#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-3Fuu8BI8YxRhmJwLF1PZf
key:                  pantry-0.8.3-3Fuu8BI8YxRhmJwLF1PZf
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  0b7f07b5dd37e69130069b8e22f5088a
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-3Fuu8BI8YxRhmJwLF1PZf
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-GDAHVM41MmSECw1rdoDU4M
    ansi-terminal-1.1-B9wXUZLJN9hAlKDPl1kvvR base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.3-Fk8xTxRwt7KEQYntPhWBKo
    casa-types-0.0.3-Co5JTn1AEZI6QUy6ckDbgW
    conduit-1.3.6.1-FOgjaZ5BRlRHF77h52RH4d
    conduit-extra-1.3.8-HAK4BGZRRQBBp2g6020i30 containers-0.6.7
    crypton-1.0.4-73G12nEmee734zT0nrdHDl
    crypton-conduit-0.2.3-Kvd15N60af2B92enuVFa6v
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.8-1bJAE7ibf1nELsCYvK76pw
    generic-deriving-1.14.7-11W7EebbJwcJW9VraBHhXa
    hackage-security-0.6.3.2-2YZxpRSmeZf2RohDPaIPQ6
    hpack-0.38.0-BaTVOfLyMUn2PuYMCOGyuQ
    http-client-0.7.19-DJLywpAf5vw3EmUrQR7uv6
    http-client-tls-0.3.6.4-E3hEWYWB8NIHsSriW8TAQ3
    http-conduit-2.3.9.1-grJXrCKMIM7vMP2p52nC3
    http-download-0.2.1.0-GRInTMEhQDZ9aaXFdaZWD1
    http-types-0.12.4-G7h7u8FYl0yCakR0583rKK
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-3gjzmu5JQ7Z8RcINbgIB8U
    path-0.9.6-DzwCLvANqVeCWSvyaMNFIJ
    path-io-1.8.2-1fzGCx45omy97zeLEZbMO7
    persistent-2.14.5.2-lkizvJJRNKHBIoX9RSFCf
    persistent-sqlite-2.13.2.0-2J2sPaxkmV4GyRGHI24L8x
    primitive-0.9.1.0-CNGLkGw87wIklpcGUTNYD
    resourcet-1.2.6-5PamoRo9UJoGlWS0o3Vev5
    rio-0.1.24.0-HkhNqlQ12L2B5Da9AuZXTD
    rio-orphans-0.1.2.0-KKasmduszxgII4nZlIxjAG
    rio-prettyprint-0.1.8.0-KGKzHoskChp8xlKMqnWyhP
    tar-conduit-0.4.1-Bvj80s6Brsv980W5TYIsC2 text-2.0.2
    text-metrics-0.3.3-4fsxFF1wzFH6gL72N3n6o2 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-8XTIqMNt1oz9DqWqu75AE0
    unliftio-0.2.25.1-IXXLacMlqlOLLV0xtb4k1H
    unordered-containers-0.2.20.1-GdjPUvgItW77rL1YhzClz
    vector-0.13.2.0-2P3Vv0GFH0i4NgSchvbpWK
    yaml-0.11.11.2-1eTJ7jydtadKIZax7fbx51
    zip-archive-0.4.3.2-H3jhqVkAnka7CNAsEl2bsj

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

